#include <OneWire.h>
#include <DallasTemperature.h>
#include <SoftwareSerial.h>

// Data wire is plugged into port 2 on the Arduino
#define SERIAL_RX 3
#define SERIAL_TX 4
#define ONE_WIRE_BUS 2

// Setup a oneWire instance to communicate with any OneWire devices
OneWire oneWire(ONE_WIRE_BUS);

// Pass our oneWire reference to Dallas Temperature.
DallasTemperature sensors(&oneWire);

// variable to hold device addresses
DeviceAddress Thermometer;

SoftwareSerial TinySerial(SERIAL_RX, SERIAL_TX);

int deviceCount = 0;

void setup(void)
{
  // start serial port
  TinySerial.begin(4800);

  // Start up the library
  sensors.begin();

  // locate devices on the bus
//  TinySerial.println("Locating devices...");
//  TinySerial.print("Found ");
//  deviceCount = sensors.getDeviceCount();
//  TinySerial.print(deviceCount, DEC);
//  TinySerial.println(" devices.");
//  TinySerial.println("");
//  
//  TinySerial.println("Printing addresses...");
//  for (int i = 0;  i < deviceCount;  i++)
//  {
//    TinySerial.print("Sensor ");
//    TinySerial.print(i+1);
//    TinySerial.print(" : ");
//    sensors.getAddress(Thermometer, i);
//    printAddress(Thermometer);
//  }
}

void loop(void)
{
  if (TinySerial.available()) {
    TinySerial.println("Locating devices...");
  TinySerial.print("Found ");
  deviceCount = sensors.getDeviceCount();
  TinySerial.print(deviceCount, DEC);
  TinySerial.println(" devices.");
  TinySerial.println("");
  
  TinySerial.println("Printing addresses...");
  for (int i = 0;  i < deviceCount;  i++)
  {
    TinySerial.print("Sensor ");
    TinySerial.print(i+1);
    TinySerial.print(" : ");
    sensors.getAddress(Thermometer, i);
    printAddress(Thermometer);
  }
  }
  }

void printAddress(DeviceAddress deviceAddress)
{ 
  for (uint8_t i = 0; i < 8; i++)
  {
    TinySerial.print("0x");
    if (deviceAddress[i] < 0x10) TinySerial.print("0");
    TinySerial.print(deviceAddress[i], HEX);
    if (i < 7) TinySerial.print(", ");
  }
  TinySerial.println("");
}
